@@ -8,6 +8,7 @@ sub init {
 }
 
 cgi 'action';
+cgi 'button';
 
 sub page_id {
     return $self->{page_id} = shift if @_;
@@ -30,3 +31,28 @@ sub page_id {
 }
 
 1;
+
+__DATA__
+
+=head1 NAME 
+
+Kwiki::CGI - Kwiki CGI Base Class
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 AUTHOR
+
+Brian Ingerson <INGY@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2004. Brian Ingerson. All rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=cut
